var classplplot_1_1core_1_1PLStream =
[
    [ "PLStream", "classplplot_1_1core_1_1PLStream.html#a1a3c367367bccfcf2060098695fefbdc", null ],
    [ "adv", "classplplot_1_1core_1_1PLStream.html#a2c4bf70b9209691f579bf4b7a9b25c92", null ],
    [ "arc", "classplplot_1_1core_1_1PLStream.html#a4eec09856b551b3e7f060ba97b5c045f", null ],
    [ "axes", "classplplot_1_1core_1_1PLStream.html#abedfa8532b2bfea1adc596e39e7be4d7", null ],
    [ "bin", "classplplot_1_1core_1_1PLStream.html#ac37bea0bb8755b68860d02de1d506d73", null ],
    [ "bop", "classplplot_1_1core_1_1PLStream.html#a613c97d564bc4bf11b8103a130ced6e7", null ],
    [ "box", "classplplot_1_1core_1_1PLStream.html#aec8f28c87f2fd22630cd278c33d93810", null ],
    [ "box3", "classplplot_1_1core_1_1PLStream.html#a48bf601858b4a737533a21a498e9656f", null ],
    [ "btime", "classplplot_1_1core_1_1PLStream.html#adf4d352cce393fb6cbbb77a1e80d9eaf", null ],
    [ "calc_world", "classplplot_1_1core_1_1PLStream.html#a602f0c73b9aa3043f631db6a2dc711f2", null ],
    [ "clear", "classplplot_1_1core_1_1PLStream.html#a073ca3bf5afc24f23da1d96adc4ebc61", null ],
    [ "ClearOpts", "classplplot_1_1core_1_1PLStream.html#a55092fa779c3c62cc862e4a9d360fa63", null ],
    [ "col0", "classplplot_1_1core_1_1PLStream.html#aec40ec5d4652ce69338cad99b54d70c0", null ],
    [ "col1", "classplplot_1_1core_1_1PLStream.html#a3ef8f0ddaaddd4a6905c6ed168b73891", null ],
    [ "colorbar", "classplplot_1_1core_1_1PLStream.html#aa0484b117287202a4f6c5cddf626ca33", null ],
    [ "configtime", "classplplot_1_1core_1_1PLStream.html#a35ac5df4cd1b8cd579e2c38a6cdb7939", null ],
    [ "cont", "classplplot_1_1core_1_1PLStream.html#a145f8762155d6948657079d1b46da264", null ],
    [ "cpstrm", "classplplot_1_1core_1_1PLStream.html#af86ec1a6bff4946d35c09f6c67bb2278", null ],
    [ "cpstrm", "classplplot_1_1core_1_1PLStream.html#ae1161fb55599b3eafcf96aadec6c1dcd", null ],
    [ "ctime", "classplplot_1_1core_1_1PLStream.html#abef2a5eabf186a7df496c742a8fc3cbc", null ],
    [ "end", "classplplot_1_1core_1_1PLStream.html#a9b557c8aba18013d1f6735ba94a72f65", null ],
    [ "end1", "classplplot_1_1core_1_1PLStream.html#a1de4bb721098266524c7a9bb2b781011", null ],
    [ "env", "classplplot_1_1core_1_1PLStream.html#a0bc67532d1acca125ad42db2900bab30", null ],
    [ "env0", "classplplot_1_1core_1_1PLStream.html#a2a12b0701f2492b3262f056190b14d34", null ],
    [ "eop", "classplplot_1_1core_1_1PLStream.html#a0448c564499b4ffa2e31d260c4b66609", null ],
    [ "errx", "classplplot_1_1core_1_1PLStream.html#a0bd1b46d3ca7426c84a138c9767d828b", null ],
    [ "erry", "classplplot_1_1core_1_1PLStream.html#a347c993e01b9fcfd6d8bc2a0f24dba97", null ],
    [ "famadv", "classplplot_1_1core_1_1PLStream.html#a084733de0f447140ef6c5c88968bf62e", null ],
    [ "fill", "classplplot_1_1core_1_1PLStream.html#a279114b6b2345da1a28dc570eb7a5c16", null ],
    [ "fill3", "classplplot_1_1core_1_1PLStream.html#a54dd0cc54593e5e9d3dcb33ea106bb53", null ],
    [ "flush", "classplplot_1_1core_1_1PLStream.html#af482a6a8749757c4494f0201b8f304fa", null ],
    [ "font", "classplplot_1_1core_1_1PLStream.html#aad93817af3bd5ddf1a3e9c9750fb540b", null ],
    [ "fontld", "classplplot_1_1core_1_1PLStream.html#aef3720b1abeee3f94c42fbf6045814bc", null ],
    [ "gchr", "classplplot_1_1core_1_1PLStream.html#a4bfb77a59ac610be6b47f87d3329b2b5", null ],
    [ "gcmap1_range", "classplplot_1_1core_1_1PLStream.html#a6daafb3432dd20452cc8d3bd3b09f97a", null ],
    [ "gcol0", "classplplot_1_1core_1_1PLStream.html#a69961b45a39665055719c5cd67a2a565", null ],
    [ "gcol0a", "classplplot_1_1core_1_1PLStream.html#ab4dd01c885058a5756de245ea5c71aea", null ],
    [ "gcolbg", "classplplot_1_1core_1_1PLStream.html#a32b1419b108e303d4fbe493984480f5b", null ],
    [ "gcolbga", "classplplot_1_1core_1_1PLStream.html#a6672c42db8403d0606f2ca1de5783987", null ],
    [ "gcompression", "classplplot_1_1core_1_1PLStream.html#adb1c2751d34bb50c58150a639035bf92", null ],
    [ "gdev", "classplplot_1_1core_1_1PLStream.html#afe3f94325662c413d7f21bf2d8f7f867", null ],
    [ "gdidev", "classplplot_1_1core_1_1PLStream.html#a337cf65763658b068e0e770d8eb71349", null ],
    [ "gdiori", "classplplot_1_1core_1_1PLStream.html#a058adda37ef5a6abc5718ac325f188a4", null ],
    [ "gdiplt", "classplplot_1_1core_1_1PLStream.html#a381c6f1eb1846ec8cef8c6a64f86f9f2", null ],
    [ "getCursor", "classplplot_1_1core_1_1PLStream.html#acaded01bf23dca6ea6df399a0def56e8", null ],
    [ "gfam", "classplplot_1_1core_1_1PLStream.html#a20e512eeb9675529ce63abbe1f5d4791", null ],
    [ "gfci", "classplplot_1_1core_1_1PLStream.html#a03bf3b650b6b8454aa98296151d56511", null ],
    [ "gfnam", "classplplot_1_1core_1_1PLStream.html#a388141d5795711129a987c7d5bcd6550", null ],
    [ "gfont", "classplplot_1_1core_1_1PLStream.html#a8a9b1dff2032f3f14bb785f424698e18", null ],
    [ "glevel", "classplplot_1_1core_1_1PLStream.html#acc6f871a5663e9c87609514875e8c765", null ],
    [ "gpage", "classplplot_1_1core_1_1PLStream.html#abf5d6bc4e66ebeed37c3dc65add5b497", null ],
    [ "gra", "classplplot_1_1core_1_1PLStream.html#a5f31c5e82b57f08c1ff72b465d0a9855", null ],
    [ "gradient", "classplplot_1_1core_1_1PLStream.html#a1532aa155d282337b21c2dddafb3cb68", null ],
    [ "griddata", "classplplot_1_1core_1_1PLStream.html#a2137f728a9645fd8bf5788c3622db47a", null ],
    [ "gspa", "classplplot_1_1core_1_1PLStream.html#a733962fd2e1a45ab3a6f0e342468c888", null ],
    [ "gver", "classplplot_1_1core_1_1PLStream.html#a09191fb8b9647fde7eab73a7fb9094ee", null ],
    [ "gvpd", "classplplot_1_1core_1_1PLStream.html#ad0353739e3a56c948a8fef7ef84b898a", null ],
    [ "gvpw", "classplplot_1_1core_1_1PLStream.html#a468598c8bb5757bb79ddd9fa0f0783b0", null ],
    [ "gxax", "classplplot_1_1core_1_1PLStream.html#a64132313e375146dae346442cc9eda57", null ],
    [ "gyax", "classplplot_1_1core_1_1PLStream.html#a59843fd9e91dcad579254ad52a1855e8", null ],
    [ "gzax", "classplplot_1_1core_1_1PLStream.html#a0289d089acfd7147e4e93460bf0a686a", null ],
    [ "hist", "classplplot_1_1core_1_1PLStream.html#a46e6f2b81864c2d95bc5a2b88c9e5288", null ],
    [ "hlsrgb", "classplplot_1_1core_1_1PLStream.html#a7345b2a3dd9cd6cb6a8833a884896971", null ],
    [ "image", "classplplot_1_1core_1_1PLStream.html#a060eb0129a73940e21b731c94fa7457e", null ],
    [ "imagefr", "classplplot_1_1core_1_1PLStream.html#af8382e9c383797d39f5c13f59f8d2256", null ],
    [ "init", "classplplot_1_1core_1_1PLStream.html#a271a21c0e4f75889e84897380db3a09a", null ],
    [ "join", "classplplot_1_1core_1_1PLStream.html#a8c35fdc786e38f7f955ebebed6edfcb9", null ],
    [ "lab", "classplplot_1_1core_1_1PLStream.html#a61801a13b028375fde4c3a46315b5ce2", null ],
    [ "legend", "classplplot_1_1core_1_1PLStream.html#a506a7ef60ea832db1bb5d20eec2b5bc5", null ],
    [ "lightsource", "classplplot_1_1core_1_1PLStream.html#ad6925a48811f84d8d68dc2b5e2c082ae", null ],
    [ "line", "classplplot_1_1core_1_1PLStream.html#aaed50b3ac0cc643206377e3b867f0318", null ],
    [ "line3", "classplplot_1_1core_1_1PLStream.html#aac6cbede200f4ceb5630f36886c1d99c", null ],
    [ "lsty", "classplplot_1_1core_1_1PLStream.html#a972e089112cb93d4497c523cfa1c26fa", null ],
    [ "map", "classplplot_1_1core_1_1PLStream.html#a7e048d1d5ae31ffa9bae5bac032b9047", null ],
    [ "mapfill", "classplplot_1_1core_1_1PLStream.html#ad0c3c19f75184750f981703167aa3d50", null ],
    [ "mapline", "classplplot_1_1core_1_1PLStream.html#a0f97a738a8c711463fbfd8446aa34fad", null ],
    [ "mapstring", "classplplot_1_1core_1_1PLStream.html#a91be867b9cee0ae295de464b3aa69f1e", null ],
    [ "maptex", "classplplot_1_1core_1_1PLStream.html#a6ea14b79d4628e0c163918ce1356611b", null ],
    [ "meridians", "classplplot_1_1core_1_1PLStream.html#a7d3305012f5956cbd2ccb7d6bbf166a2", null ],
    [ "mesh", "classplplot_1_1core_1_1PLStream.html#a8c4ba1056b1b1d2379d3ad1ebd534d98", null ],
    [ "meshc", "classplplot_1_1core_1_1PLStream.html#a326cadbcaac308d945efd1812477c99f", null ],
    [ "minMax2dGrid", "classplplot_1_1core_1_1PLStream.html#a07ad2b3ea33c01458e2d0a95f2f8d846", null ],
    [ "mtex", "classplplot_1_1core_1_1PLStream.html#a69b779a3201cb28a100f6248f0a71bac", null ],
    [ "mtex3", "classplplot_1_1core_1_1PLStream.html#aa6e38b9f788dcd8cf74ec5d7d0abe163", null ],
    [ "openlib", "classplplot_1_1core_1_1PLStream.html#ab60146b9e58139fa4042edc86d25b5c0", null ],
    [ "OptUsage", "classplplot_1_1core_1_1PLStream.html#af6dd6dd9be106f386255eafc03d5c5fa", null ],
    [ "parseopts", "classplplot_1_1core_1_1PLStream.html#adf97fc68b00073c12080ffaa0428ec07", null ],
    [ "pat", "classplplot_1_1core_1_1PLStream.html#ad524ddef05e352c0355780ea9af48679", null ],
    [ "path", "classplplot_1_1core_1_1PLStream.html#a76f7eb3b8e7186331aaa9cb02782ad68", null ],
    [ "plot3d", "classplplot_1_1core_1_1PLStream.html#ac13c1c45e53a12548e04e49c906d4955", null ],
    [ "plot3d", "classplplot_1_1core_1_1PLStream.html#a8feef9f9155b379286817282a2f3d077", null ],
    [ "plot3dc", "classplplot_1_1core_1_1PLStream.html#ab45753142252736c0941e3475fc29d03", null ],
    [ "plot3dcl", "classplplot_1_1core_1_1PLStream.html#a3090d1fdfd56534eba93f6dcfcd8f407", null ],
    [ "poin", "classplplot_1_1core_1_1PLStream.html#aa8f60d0119f8887a088f95cf971d9817", null ],
    [ "poin3", "classplplot_1_1core_1_1PLStream.html#a6371aa3ca011574756d2f5420b58188e", null ],
    [ "poly3", "classplplot_1_1core_1_1PLStream.html#ad90a1d3200f37d99b3f1685e33ffb1bb", null ],
    [ "poly3", "classplplot_1_1core_1_1PLStream.html#a38c31bf9f1db8d1c2a4ef2bf5534b954", null ],
    [ "prec", "classplplot_1_1core_1_1PLStream.html#a4a4af6e43fa45444ca1bd8bfc92fab5b", null ],
    [ "psty", "classplplot_1_1core_1_1PLStream.html#aa8332c5946208fae23106b2ad1daf5cf", null ],
    [ "ptex", "classplplot_1_1core_1_1PLStream.html#a10ab01fa573ba565a47c6497cf3fc18a", null ],
    [ "ptex3", "classplplot_1_1core_1_1PLStream.html#a9a290e4234c18c4083eae08d24181010", null ],
    [ "randd", "classplplot_1_1core_1_1PLStream.html#af99be78ac0c125a40919934c4454316e", null ],
    [ "replot", "classplplot_1_1core_1_1PLStream.html#acb6bdaadb35eb7b522da1603d2e10240", null ],
    [ "ResetOpts", "classplplot_1_1core_1_1PLStream.html#ac39e41ee297ba3564b510f74bbf90334", null ],
    [ "rgbhls", "classplplot_1_1core_1_1PLStream.html#afb7e2f8d9a1d008814a2c2ded3082f52", null ],
    [ "schr", "classplplot_1_1core_1_1PLStream.html#af7ba91b72a3ca54a0152a753d9c7c279", null ],
    [ "scmap0", "classplplot_1_1core_1_1PLStream.html#ae37990a90afae0aa89be179192a7ac78", null ],
    [ "scmap0a", "classplplot_1_1core_1_1PLStream.html#a819df61b8eabba4063d1007ed8a81460", null ],
    [ "scmap0n", "classplplot_1_1core_1_1PLStream.html#a5ddcbcf4953abeaf102d7e9b6777f167", null ],
    [ "scmap1", "classplplot_1_1core_1_1PLStream.html#ae9786cca688d3556f5692d591119be92", null ],
    [ "scmap1_range", "classplplot_1_1core_1_1PLStream.html#a324cb2f84701ad542c2c7c61939f0a65", null ],
    [ "scmap1a", "classplplot_1_1core_1_1PLStream.html#a631fa9af17504f46f375bec0dda0e62c", null ],
    [ "scmap1l", "classplplot_1_1core_1_1PLStream.html#a6ff9777b747c7f15c73add69911d85a8", null ],
    [ "scmap1l", "classplplot_1_1core_1_1PLStream.html#acd4280c1294f833486fec09a242f2d61", null ],
    [ "scmap1l", "classplplot_1_1core_1_1PLStream.html#a8776c41aeed00760813751a1b493ef8c", null ],
    [ "scmap1la", "classplplot_1_1core_1_1PLStream.html#aeedab8b88f4c1a55c87c50ed8decfc5c", null ],
    [ "scmap1la", "classplplot_1_1core_1_1PLStream.html#addd8b90f53a8fbeb17b1000d4f914379", null ],
    [ "scmap1n", "classplplot_1_1core_1_1PLStream.html#a5ec6aea3ee8f0def1107bddd921d26a2", null ],
    [ "scol0", "classplplot_1_1core_1_1PLStream.html#a81f7d1a0a0ffcecb0d0e9cceff82cd74", null ],
    [ "scol0a", "classplplot_1_1core_1_1PLStream.html#a0a423a93e7683fed4a3019dfb0f50f51", null ],
    [ "scolbg", "classplplot_1_1core_1_1PLStream.html#a965a0b12a0e06ba0f2e2c3e46b947628", null ],
    [ "scolbga", "classplplot_1_1core_1_1PLStream.html#a0a3efe301f606cb80b01315f23cfa197", null ],
    [ "scolor", "classplplot_1_1core_1_1PLStream.html#a3dc352ef86e92686bc46d9120f0095a7", null ],
    [ "scompression", "classplplot_1_1core_1_1PLStream.html#a029e7d3efd10cf68ff6f400a05237020", null ],
    [ "sdev", "classplplot_1_1core_1_1PLStream.html#a5196cd6e708c866b191bd2d320d63ba6", null ],
    [ "sdidev", "classplplot_1_1core_1_1PLStream.html#a2a98159d876ea8a156d5317ea8ce9cf2", null ],
    [ "sdimap", "classplplot_1_1core_1_1PLStream.html#a9c0378258e43879ec0141903e42918d1", null ],
    [ "sdiori", "classplplot_1_1core_1_1PLStream.html#a182ed2fce6ae0f031666d2070d911657", null ],
    [ "sdiplt", "classplplot_1_1core_1_1PLStream.html#a5fad0b233116297d056ced74bb7e5c4a", null ],
    [ "sdiplz", "classplplot_1_1core_1_1PLStream.html#a7e76132075f6ab97135b3a2033615a74", null ],
    [ "seed", "classplplot_1_1core_1_1PLStream.html#a5ae6210927efe49b154ce30a92a30714", null ],
    [ "sesc", "classplplot_1_1core_1_1PLStream.html#a760e75352398c93cdc387f4fa228f0ef", null ],
    [ "set_stream", "classplplot_1_1core_1_1PLStream.html#a56112b906f777ec217c1999d798d5475", null ],
    [ "setcontlabelformat", "classplplot_1_1core_1_1PLStream.html#a26de6d3e854a9d0e4e3e657aa509ed1d", null ],
    [ "setcontlabelparam", "classplplot_1_1core_1_1PLStream.html#a3d1ea08cd349661c857f76bc89f01456", null ],
    [ "setopt", "classplplot_1_1core_1_1PLStream.html#a5764242b32c1eb9df2597348955bba91", null ],
    [ "SetUsage", "classplplot_1_1core_1_1PLStream.html#a10685b4caa2170346612951360302171", null ],
    [ "sfam", "classplplot_1_1core_1_1PLStream.html#a8e83fed5c57fbe652495efb4d729bbad", null ],
    [ "sfci", "classplplot_1_1core_1_1PLStream.html#adaa8c2d5a5f11c417ad9dc584d904b9d", null ],
    [ "sfnam", "classplplot_1_1core_1_1PLStream.html#a5ca21903444bdb8ac82521fd9d9c641e", null ],
    [ "sfont", "classplplot_1_1core_1_1PLStream.html#a9613f3dfc5a8524bc266a49896b9b164", null ],
    [ "shade", "classplplot_1_1core_1_1PLStream.html#a9911be10af004c2000682b415df22fd3", null ],
    [ "shade", "classplplot_1_1core_1_1PLStream.html#a8079b267b9c7c804fda783453ffe3b94", null ],
    [ "shades", "classplplot_1_1core_1_1PLStream.html#a1deb5e74a277f4dfe20687e8045326a4", null ],
    [ "shades", "classplplot_1_1core_1_1PLStream.html#a8229fe6484e494ee6ea191d94d6323f1", null ],
    [ "slabelfunc", "classplplot_1_1core_1_1PLStream.html#aac1e08d0ba286c96a1044d48fdcc9801", null ],
    [ "slabelfunc", "classplplot_1_1core_1_1PLStream.html#a68097f246320f697b2e6798edafb9acf", null ],
    [ "smaj", "classplplot_1_1core_1_1PLStream.html#a0641800123d087a7db20e04584367bf6", null ],
    [ "smin", "classplplot_1_1core_1_1PLStream.html#a16b45b50dbeac21e721203283e0651f1", null ],
    [ "sori", "classplplot_1_1core_1_1PLStream.html#a75d996a1d1134ed72be2fda40f6c6f6a", null ],
    [ "spage", "classplplot_1_1core_1_1PLStream.html#a7cf4b489aafcb868e9b2370c1ad89fda", null ],
    [ "spal0", "classplplot_1_1core_1_1PLStream.html#adf0881b254d70f1ccb5c349cda1b929b", null ],
    [ "spal1", "classplplot_1_1core_1_1PLStream.html#a45641cf8ae39193004063bd037681690", null ],
    [ "spause", "classplplot_1_1core_1_1PLStream.html#ae3a8e4aa533fcdce80047bf761126dc8", null ],
    [ "spause", "classplplot_1_1core_1_1PLStream.html#a5b45e6a0878939e744800c6c3cc6b834", null ],
    [ "sstrm", "classplplot_1_1core_1_1PLStream.html#a4e6236cff7afbd44f711175c34c453ae", null ],
    [ "ssub", "classplplot_1_1core_1_1PLStream.html#abbde3bca35ffa532467d1e73630002aa", null ],
    [ "ssym", "classplplot_1_1core_1_1PLStream.html#af9a45c091770fcd591f5dcd7602f5b0b", null ],
    [ "star", "classplplot_1_1core_1_1PLStream.html#a3ab032f726a13dc58de548518a285c3f", null ],
    [ "start", "classplplot_1_1core_1_1PLStream.html#ae3d2f753a2223e8d58006f2b0d887056", null ],
    [ "stransform", "classplplot_1_1core_1_1PLStream.html#ad7b4bb408082598b5d1e7f2e46fb8583", null ],
    [ "string", "classplplot_1_1core_1_1PLStream.html#a59c36255f476218466f3026a22b074d8", null ],
    [ "string3", "classplplot_1_1core_1_1PLStream.html#ad3bec041652df50bdfbb224b6c006039", null ],
    [ "stripa", "classplplot_1_1core_1_1PLStream.html#adbd8a4e9a8fab967eef1d352eb42bdb9", null ],
    [ "stripc", "classplplot_1_1core_1_1PLStream.html#aebf440a490520984273b438861830aec", null ],
    [ "stripc", "classplplot_1_1core_1_1PLStream.html#a40da49908f94bbe0828e717dbe1608b9", null ],
    [ "stripd", "classplplot_1_1core_1_1PLStream.html#a0f2796c41818638c5da84268d291c174", null ],
    [ "styl", "classplplot_1_1core_1_1PLStream.html#a98a4e6d039328528e9da1298a36ea644", null ],
    [ "surf3d", "classplplot_1_1core_1_1PLStream.html#a470a4114511cac5cd5f8a9b8fb9426ac", null ],
    [ "surf3dl", "classplplot_1_1core_1_1PLStream.html#a53a1ec47df28491ea66f1f1bc412f6d6", null ],
    [ "svect", "classplplot_1_1core_1_1PLStream.html#a8cecc9ae9ac2fea1541d88ffc4133759", null ],
    [ "svect", "classplplot_1_1core_1_1PLStream.html#aaddbb180e6e01f79f2caa99a93c6292c", null ],
    [ "svpa", "classplplot_1_1core_1_1PLStream.html#ab7345b4e3d0bb9aad47aa4307eabe7a3", null ],
    [ "sxax", "classplplot_1_1core_1_1PLStream.html#a042ac773b7a66ddd1df561a585d47724", null ],
    [ "syax", "classplplot_1_1core_1_1PLStream.html#a887538d19bbce2b5ac9a437911600136", null ],
    [ "sym", "classplplot_1_1core_1_1PLStream.html#a8d04c5ea187d514987f0a9499260ab7b", null ],
    [ "szax", "classplplot_1_1core_1_1PLStream.html#a2473fdf4cb729307c112335279f5e7ef", null ],
    [ "text", "classplplot_1_1core_1_1PLStream.html#aadffc2af4b9889d9586f56d2fc073536", null ],
    [ "timefmt", "classplplot_1_1core_1_1PLStream.html#a691f55bf90b757df6aaca9fef7d1e20f", null ],
    [ "vasp", "classplplot_1_1core_1_1PLStream.html#a5ed6e62e306206e5f28e0f7162363409", null ],
    [ "vect", "classplplot_1_1core_1_1PLStream.html#a95ec3d6f1d48da493e901aae87b423e7", null ],
    [ "vpas", "classplplot_1_1core_1_1PLStream.html#a0343ded0612eceaede5fcb5f8635be40", null ],
    [ "vpor", "classplplot_1_1core_1_1PLStream.html#a68f6f3430b9e23cadf32be4ee987dfc9", null ],
    [ "vsta", "classplplot_1_1core_1_1PLStream.html#a94b0cf12968032aedb1419a4c274f5c0", null ],
    [ "w3d", "classplplot_1_1core_1_1PLStream.html#ab9cace93368bb2c75e80bc40ea614880", null ],
    [ "width", "classplplot_1_1core_1_1PLStream.html#a55792ad22e042bc8f3a0ea8f1effb401", null ],
    [ "width", "classplplot_1_1core_1_1PLStream.html#a33e0353dc3495c37f208c58d1206b3bc", null ],
    [ "wind", "classplplot_1_1core_1_1PLStream.html#a9ff162968aefdc6773fb263e09fdf02c", null ],
    [ "xormod", "classplplot_1_1core_1_1PLStream.html#ae492899fa93e15c29a853ae786fdee79", null ],
    [ "xormod", "classplplot_1_1core_1_1PLStream.html#ac1693421b67dc976d17a3ff4e78ecbe0", null ]
];